@@ -1,9 +1,9 @@
 package Net::Twitter::Core;
 use 5.008001;
 use Moose;
-use MooseX::MultiInitArg;
+use MooseX::Aliases;
 use Carp;
-use JSON::Any qw/XS JSON/;
+use JSON;
 use URI::Escape;
 use HTTP::Request::Common;
 use Net::Twitter::Error;
@@ -18,18 +18,16 @@ use Try::Tiny;
 use namespace::autoclean;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.17001';
+our $VERSION = '3.18001';
 
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
 has useragent_class => ( isa => 'Str', is => 'ro', default => 'LWP::UserAgent' );
 has useragent_args  => ( isa => 'HashRef', is => 'ro', default => sub { {} } );
-has username        => ( traits => [qw/MooseX::MultiInitArg::Trait/],
-                         isa => 'Str', is => 'rw', predicate => 'has_username',
-                         init_args => [qw/user/] );
-has password        => ( traits => [qw/MooseX::MultiInitArg::Trait/],
-                         isa => 'Str', is => 'rw', predicate => 'has_password',
-                         init_args => [qw/pass/] );
+has username        => ( isa => 'Str', is => 'rw', predicate => 'has_username',
+                         alias => 'user' );
+has password        => ( isa => 'Str', is => 'rw', predicate => 'has_password',
+                         alias => 'pass' );
 has ssl             => ( isa => 'Bool', is => 'ro', default => 0 );
 has netrc           => ( isa => 'Str', is => 'ro', predicate => 'has_netrc' );
 has netrc_machine   => ( isa => 'Str', is => 'ro', default => 'api.twitter.com' );
@@ -43,21 +41,22 @@ has clienturl       => ( isa => 'Str', is => 'ro', default => 'http://search.cpa
 has _base_url       => ( is => 'rw' ); ### keeps role composition from bitching ??
 has _json_handler   => (
     is      => 'rw',
-    default => sub { JSON::Any->new(utf8 => 1) },
-    handles => { _from_json => 'from_json' },
+    default => sub { JSON->new->utf8 },
+    handles => { _from_json => 'decode' },
 );
 
-sub _synthetic_args { qw/authenticate since/ }
+sub _legacy_synthetic_args { qw/authenticate since/ }
 
-sub _extract_synthetic_args {
+sub _remap_legacy_synthetic_args {
     my ( $self, $args ) = @_;
 
-    my $synthetic_args = {};
-    for my $k ( $self->_synthetic_args ) {
-        $synthetic_args->{$k} = delete $args->{$k} if exists $args->{$k};
-    }
+    $args->{"-$_"} = delete $args->{$_} for grep exists $args->{$_}, $self->_legacy_synthetic_args;
+}
 
-    return $synthetic_args;
+sub _natural_args {
+    my ( $self, $args ) = @_;
+
+    map { $_ => $args->{$_} } grep !/^-/, keys %$args;
 }
 
 around BUILDARGS => sub {
@@ -140,12 +139,12 @@ sub _encode_args {
 }
 
 sub _json_request { 
-    my ($self, $http_method, $uri, $args, $authenticate, $synthetic_args, $dt_parser) = @_;
+    my ($self, $http_method, $uri, $args, $authenticate, $dt_parser) = @_;
     
     my $msg = $self->_prepare_request($http_method, $uri, $args, $authenticate);
     my $res = $self->_send_request($msg);
 
-    return $self->_parse_result($res, $synthetic_args, $dt_parser);
+    return $self->_parse_result($res, $args, $dt_parser);
 }
 
 sub _prepare_request {
@@ -153,27 +152,29 @@ sub _prepare_request {
 
     my $msg;
 
-    $self->_encode_args($args);
+    my %natural_args = $self->_natural_args($args);
+
+    $self->_encode_args(\%natural_args);
 
     if ( $http_method =~ /^(?:GET|DELETE)$/ ) {
-        $uri->query_form($args);
+        $uri->query_form(%natural_args);
         $msg = HTTP::Request->new($http_method, $uri);
     }
     elsif ( $http_method eq 'POST' ) {
         # if any of the arguments are (array) refs, use form-data
-        $msg = (first { ref } values %$args)
+        $msg = (first { ref } values %natural_args)
              ? POST($uri,
                     Content_Type => 'form-data',
-                    Content      => [ %$args ],
+                    Content      => \%natural_args,
                )
-             : POST($uri, $args)
+             : POST($uri, \%natural_args)
              ;
     }
     else {
         croak "unexpected HTTP method: $http_method";
     }
 
-    $self->_add_authorization_header($msg, $args) if $authenticate;
+    $self->_add_authorization_header($msg, \%natural_args) if $authenticate;
 
     return $msg;
 }
@@ -209,7 +210,7 @@ sub _decode_html_entities { shift->_decode_html_entities_visitor->visit(@_) }
 sub _inflate_objects { return $_[2] }
 
 sub _parse_result {
-    my ($self, $res, $synthetic_args, $datetime_parser) = @_;
+    my ($self, $res, $args, $datetime_parser) = @_;
 
     # workaround for Laconica API returning bools as strings
     # (Fixed in Laconi.ca 0.7.4)
@@ -220,7 +221,7 @@ sub _parse_result {
     $self->_decode_html_entities($obj) if $obj && $self->decode_html_entities;
 
     # filter before inflating objects
-    if ( (my $since = delete $synthetic_args->{since}) && defined $obj ) {
+    if ( (my $since = delete $args->{-since}) && defined $obj ) {
         $self->_filter_since($datetime_parser, $obj, $since);
     }
 
@@ -297,6 +298,18 @@ sub _contains_statuses {
     return exists $e->{created_at} && exists $e->{text} && exists $e->{id};
 }
 
+sub _user_or_undef {
+    my ( $self, $orig, $type, @rest ) = @_;
+
+    return try {
+        $orig->($self, @rest);
+    }
+    catch {
+        die $_ unless /The specified user is not a $type of this list/;
+        undef;
+    };
+}
+
 1;
 
 __END__
