@@ -34,7 +34,7 @@ EOT
 
     path     => 'search',
     method   => 'GET',
-    params   => [qw/q callback lang rpp page since_id geocode show_user/],
+    params   => [qw/q callback lang locale rpp page since_id until geocode show_user result_type/],
     required => [qw/q/],
     returns  => 'HashRef',
 );
